/*
  OS Pixie MK2 Enclosure - Drawn by MIke Kitchen (Mike_K on mode-zero.uk)
  There are separate files for the enclosure, base, lid and switch

  1. Construct the side outline with cylinders
  2. Draw the other side using mirror
  3. Use "hull()" to get the basic smooth outline shape
  4. Repeat the above with reduced dimensions to hollow it out (completely remove the inside of the enclosure)
  5. Remove the push-button switch
  6. Remove the switch + mounting holes
  7. Remove the aerial hole
  8. Remove the FrSky bind PCB switch and LED holes
  10. Add the FrSky bind PCB mounts
*/

$fn = 80; //Render a bit quicker (not smoother!)


union() { //Bits to add

  difference() { //Draw the enclosure then remove the centre and other bits

    union() { //Bits to add
      hull() { //make a smooth shape around the "sides" of the enclosure
        side(0, 19);

        mirror() {  //Draw the other side of the enclosure
          side(0, 19);
        }
      }
      translate ([-15.5, 55, 9.5]) { //Add "half cylinder" on top of enclosure
        cylinder (r = 5, h = 19, center = true);
      }
    }

    union() { //Bits to remove
      hull() { //make a smooth shape around the "centre" bit to be removed
        side(2, 20);

        mirror() {  //Draw the other side of the enclosure
          side(2, 20);

        }
      }

      translate ([0, -56, -14]) { //remove "thumb access" to remove the lid
        rotate([90, 0, 0]) {
          cylinder (r = 16, h = 2, center = true);
        }
      }
      //On-Off Switch
      translate ([-35, 10, 9]) {
        rotate(a = [0, 90, 0]) {
          union() {

            //The switch leaver cut-out
            cube ([5, 8, 10], center = true);

            //The switch mounting hole cut-outs
            translate ([0, 9, 0]) {
              cylinder (d = 3, h = 10, center = true);
            }
            translate ([0, -9, 0]) {
              cylinder (d = 3, h = 10, center = true);
            }
          }
        }
      }

      //Pushbutton Switch
      translate ([-31, 40, 9]) {
        rotate(a = [0, 90, 0]) {
          cylinder (d = 12, h = 6, center = true);
        }
      }

      //2.4 Antenna cut-out. Not to scale, but further enough from the edge so a sma connector fits OK

      translate ([-5, 55, 12]) {
        rotate(a = [90, 0, 0]) {
          cylinder (d = 6, h = 6, center = true);
        }
      }
            translate ([31, 40, 8.5]) { //FrSky bind switch
        rotate(a = [90, 0, 90]) {
          cylinder (d = 4, h = 6, center = true);
        }
      }
      translate ([31, 31.5, 8.5]) { //FrSky bind LED
        rotate(a = [90, 0, 90]) {
          cylinder (d = 4, h = 6, center = true);
        }
      }
    }
  }
  
  //Mounts and holes for magnets to hold the lid on, FrSky Bind switch and LED PCB
  difference() {
    union() {
      translate ([0, 54, 4]) { //Magnet mount (top) to hold lid on
          cylinder (d = 10, h = 4, center = true);
      }  
      translate ([0, -54, 4]) { //Magnet mount (bottom) to hold lid on
          cylinder (d = 10, h = 4, center = true);
      } 
      translate ([29, 47, 6]) { //FrSky bind button mounts
        rotate(a = [90, 0, 90]) {
          cylinder (d = 5, h = 7, center = true);
        }
      }
      translate ([29, 26.5, 6]) { //second mount
        rotate(a = [90, 0, 90]) {
          cylinder (d = 5, h = 7, center = true);
        }
      }
    //The three vertical lines on the left of the enclosure  
    translate ([33.5, 11, 9]) {
      cube ([0.5, 1, 18], center = true);
    }
    translate ([33.5, 19, 9]) {
      cube ([0.5, 1, 18], center = true);
    }
    translate ([33.5, 27, 9]) {
      cube ([0.5, 1, 18], center = true);
    }      
    }

    //remove disk for a 4mm x 1mm magnets
      translate ([0, 52, 2]) { //Magnet hole (top) to hold lid on
          cylinder (d = 4, h = 2, center = true);
      }  
      translate ([0, -52, 2]) { //Magnet hole (bottom) to hold lid on
          cylinder (d = 4, h = 2, center = true);
      }
    translate ([0, 61, 6]) { //mag mount - remove half cylinder
        cube ([10,10,10], center = true);

    }
    translate ([0, -61, 6]) { //mag mount - remove half cylinder
        cube ([10,10,10], center = true);

    }
        
    translate ([29, 47, 6]) { //FrSky mounts screw hole
      rotate(a = [90, 0, 90]) {
        cylinder (d = 1, h = 8, center = true);
      }
    }
    translate ([29, 26.5, 6]) { //second screw hole
      rotate(a = [90, 0, 90]) {
        cylinder (d = 1, h = 7, center = true);
      }
    }
}

}


module side(wallThick, height) { //module to draw a side. Its used to draw both sides

  //Dimensions of enclosure width /2 (half width)
  /*
    w0 = 33; //33 * 2 = 66
    w1 = 33.25; //33.25 * 2 = 66.5
    w2 = 33.5; //33.5 * 2 = 67
    w3 = 33.5; //33.5 * 2 = 67
    w4 = 33.5; //33.5 * 2 = 67
    w5 = 33.25; //33.25 * 2 = 66.5
    w6 = 32.75; //32.75 * 2 = 65.5
    w7 = 32.25; //32.25 * 2 = 64.5
    w8 = 31.25; //31.25 * 2 = 62.5
    w9 = 30; //33 * 2 = 60
    w10 = 29; //29 * 2 = 58
    w11 = 28; //28 * 2 = 56
  */
  enclosureWidth = [33, 33.25, 33.5, 33.5, 33.5, 33.25, 32.75, 32.25, 31.25, 30, 29, 28];

  length = 112; //top to bottom
  //height = 24; //without lid
  r1 = 5; //corner radius top and bottom

  union() { //All the bits to add to the side

      translate ([enclosureWidth[0] - r1 - wallThick, (length / 2) - r1 - wallThick, height / 2]) {
        cylinder (r = r1, h = (height), center = true);
      }
      
    for (i = [1:10]) { //for the 10 widths between the top and bottom

      translate ([enclosureWidth[i] - r1 - wallThick, (length / 2) - (i * 10) - wallThick, height / 2]) {
        cylinder (r = r1, h = (height), center = true);
      }
    }

    //bottom width dimension.
    translate ([enclosureWidth[11] - r1 - wallThick, (length / 2) - 112 + r1 + wallThick, height / 2]) {
      cylinder (r = r1, h = (height), center = true);
    }

  }
}

