/*
  OS Pixie MK2 Lid

  Drawn by Mike Kitchen (Mike_K on mode-zero.uk)
  There are separate files for the enclosure, enclosure base, lid and switch

  The main enclosure is made in two parts and the parts are glued together. This means they can be made with little or no supports.
  The lid is held on with small magnets so no central pillar is needed and the thumb screw is for appearance only and is non-functional (it is glued into position)

*/

$fn = 80; //Render a bit quicker (not smoother!)

union() {
  difference() {
    union() {
      difference() {
        union() { //Make the basic lid shape
          translate ([0, 0, 3]) {
            hull() { //make a smooth shape around the enclosure
              side(0, 7, 5);
              top(0, 7);
              mirror() {  //Draw the other side of the enclosure
                side(0, 7, 5);
                top(0, 7);
              }
            }
          }
          translate ([0, 0, 1]) {
            hull() { //make a smooth shape around the enclosure
              side(2, 5, 5);
              mirror() {  //Draw the other side of the enclosure
                side(2, 5, 5);
              }
            }
          }
        }
        //remove bits from the enclosure
        difference() {
          union() {//make a "mask" remove bits, then remove what's left from the lid basic structure
            translate ([0, 0, 9]) {
              hull() { //make a smooth shape around the enclosure
                side(3, 5, 3);
                mirror() {  //Draw the other side of the enclosure
                  side(3, 5, 3);
                }
              }
            }
          }
          union() {
            translate ([0, 20.5, 9]) {
              cube([72, 23.5, 5], center = true);
            }
            translate ([0, -38.5, 9]) {
              cube([72, 11.5, 5], center = true);
            }
            translate ([0, -16, 5]) {
              cylinder (r = 7, h = 10, center = true);
            }
          }
        }
        translate ([0, 0, 1]) { //hollow out basic lid shape
          hull() { //make a smooth shape around the enclosure
            side(4, 5, 5);
            mirror() {  //Draw the other side of the enclosure
              side(4, 5, 5);
            }
          }
        }
      }
      intersection() {
        translate ([0, 0, 9]) {
          hull() { //make a smooth shape around the enclosure
            side(3, 5, 3);
            mirror() {  //Draw the other side of the enclosure
              side(3, 5, 3);
            }
          }
        }
        union() {
          translate ([38, 43.75, 9.5]) {
            rotate([0, 0, 90]) {
              crissCross(30, 52);
            }
          }
          translate ([50, -13, 9.5]) {
            rotate([0, 0, 90]) {
              crissCross(50, 85);
            }
          }
          translate ([33, -48.5, 9.5]) {
            rotate([0, 0, 90]) {
              lines(10, 40);
            }
          }
        }
      }
    }
    union() { //Join text and triangles so can move and rotate "as one"
      translate ([-16.75, 20, 9]) { //
        scale([1.6, 1, 1]) linear_extrude(height = 2, center = true) {
          text("P", font = "Arial:style=Bold", size = 8, halign = "center", valign = "center", center = true);
        }
      }
      translate ([-8.25, 20, 9]) { //
        scale([1.6, 1, 1]) linear_extrude(height = 2, center = true) {
          text("I", font = "Arial:style=Bold", size = 8, halign = "center", valign = "center", center = true);
        }
      }
      translate ([0, 20, 9]) { //
        scale([1.6, 1, 1]) linear_extrude(height = 2, center = true) {
          text("X", font = "Arial:style=Bold", size = 8, halign = "center", valign = "center", center = true);
        }
      }
      translate ([8.25, 20, 9]) { //
        scale([1.6, 1, 1]) linear_extrude(height = 2, center = true) {
          text("I", font = "Arial:style=Bold", size = 8, halign = "center", valign = "center", center = true);
        }
      }
      translate ([16.75, 20, 9]) { //
        scale([1.6, 1, 1]) linear_extrude(height = 2, center = true) {
          text("E", font = "Arial:style=Bold", size = 8, halign = "center", valign = "center", center = true);
        }
      }

      translate ([-6.25, -38.5, 9]) { //
        scale([1.6, 1, 1]) linear_extrude(height = 2, center = true) {
          text("O", font = "Arial:style=Bold", size = 6, halign = "center", valign = "center", center = true);
        }
      }
      translate ([6.25, -38.5, 9]) { //
        scale([1.6, 1, 1]) linear_extrude(height = 2, center = true) {
          text("S", font = "Arial:style=Bold", size = 6, halign = "center", valign = "center", center = true);
        }
      }

      translate ([-20, -38.5, 9]) {      //The prism/triangle either side of the text
        prism(5.5, 3.5, 1.5);

      }
      mirror([1, 0, 0]) { //There are two triangles either side
        translate ([-20, -38.5, 9]) {
          prism(5.5, 3.5, 1.5);
        }
      }

      translate ([0, 12, 9]) {
        cube([56, 1, 2], center = true);
      }
      translate ([0, 27, 9]) {
        cube([56, 1, 2], center = true);
      }
      translate ([0, -16, 6]) {
        cylinder (d = 3, h = 12, center = true, $fn = 10);
      }
    }
  }
  //Add a bit of the "E" from the PIXIE text (arial isn't quite the correct font)
  translate ([21.5, 20, 9]) {
    cube([5, 4, 2], center = true);
  }
}

/*
  Dimensions of enclosure widths /2 (half width) at 10mm vertical intervals

  width0 = 33; //66
  width1 = 33.25; //66.5
  width2 = 33.5; //67
  width3 = 33.5; //67
  width4 = 33.5; //67
  width5 = 33.25; //66.5
  width6 = 32.75; //65.5
  width7 = 32.25; //64.5
  width8 = 31.25; //62.5
  width9 = 30; //60
  width10 = 29; //58
  width11 = 28; //56
*/
enclosureWidth = [33, 33.25, 33.5, 33.5, 33.5, 33.25, 32.75, 32.25, 31.25, 30, 29, 28];

length = 112; //top to bottom
//height = 7; //without lid
r1 = 5; //corner radius top and bottom
r2 = 3; //corner radius around the face

/*The Pixie MK2 transmitter widths from the top to the bottom
  in 10mm steps. The bottom (last) dimension is 12mm
  as case is 112mm tall (length)
*/

module side(wallThick, height, topRadius) { //module to draw a side. Its used to draw both sides

  union() { //All the bits to add to the side

    //top width dimension
    translate ([topRadius + wallThick - enclosureWidth[0], (length / 2) - wallThick - topRadius, (height - r2) / 2]) {
      cylinder (r = topRadius, h = (height - r2), center = true);
    }

    for (i = [1:10]) { //for the 10 widths between the top and bottom
      //echo(enclosureWidth[i]);
      translate ([5 + wallThick - enclosureWidth[i], (length / 2) - (i * 10), (height - r2) / 2]) {
        cylinder (r = 5, h = (height - r2), center = true);
      }
    }

    //bottom width dimension.
    translate ([topRadius + wallThick - enclosureWidth[11], (length / 2) - 112 + topRadius + wallThick, (height - r2) / 2]) {
      cylinder (r = topRadius, h = (height - r2), center = true);
    }
  }
}

module top(wallThick, height) { //module to draw the top radius. Its used to draw both sides



  union() { //All the bits to add to the side

    //Extrude the sphere radius r2 (3mm) around the corner radius r1 (5mm)
    translate ([r1 + wallThick - enclosureWidth[0], (length / 2) - wallThick - r1, (height - r2)]) {
      rotate_extrude(convexity = 10)
      translate([2, 0, 0])
      difference() {
        circle(r = 3);
        polygon( points = [[0, -3], [-3, -3], [-3, 3], [0, 3]] );
      }
    }

    for (i = [1:10]) { //for the 10 widths between the top and bottom
      //echo(enclosureWidth[i]);
      translate ([r1 + wallThick - enclosureWidth[i], (length / 2) - (i * 10), (height - r2) / 2]) {
        cylinder (r = r1, h = (height - r2), center = true);
      }
      translate ([r2 + wallThick - enclosureWidth[i], (length / 2) - (i * 10), (height - r2)]) {
        sphere(r = r2, center = true);
      }
    }


    //bottom width dimension.

    //Extrude the sphere radius r2 (3mm) around the corner radius r1 (5mm)
    translate ([r1 + wallThick - enclosureWidth[11], (length / 2) - 112 + 5 + wallThick, (height - r2)]) {
      rotate_extrude(convexity = 10)
      translate([2, 0, 0])
      difference() {
        circle(r = 3);
        polygon( points = [[0, -3], [-3, -3], [-3, 3], [0, 3]] );
      }
    }
  }
}


module crissCross(length, number) {
  union() {
    for (i = [1:number]) { //for the number of lines
      translate ([0, 1.5 * i, 0]) {
        rotate([0, 0, 25]) {
          cube([length, 0.5, .5], center = true);
        }
        rotate([0, 0, -25]) {
          cube([length, 0.5, .5], center = true);
        }
        translate ([0, 0, 0.25]) {
          rotate([90, 0, 65]) {
            cylinder (r = .25, h = length, center = true, $fn = 10);
          }
          rotate([90, 0, -65]) {
            cylinder (r = .25, h = length, center = true, $fn = 10);
          }
        }
      }
    }
  }
}

module lines(length, number) {
  union() {
    for (i = [1:number]) { //for the number of lines
      translate ([0, 1.5 * i, 0]) {
        cube([length, 0.5, 0.5], center = true);
        translate ([0, 0, 0.25]) {
          rotate([0, 90, 0]) {
            cylinder (r = .25, h = length, center = true, $fn = 10);
          }
        }
      }
    }
  }
}

module prism(l, h, d) {
  polyhedron(
    points = [[0, 0, 0], [0, 0, d], [l, h / 2, 0], [l, -h / 2, 0], [l, h / 2, d], [l, -h / 2, d]],
    faces = [[0, 2, 4, 1], [0, 1, 5, 3], [0, 3, 2], [1, 4, 5], [2, 3, 5, 4]], center = true);
}